@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.11';
+our $VERSION = '1.12';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -295,7 +295,7 @@ sub _args {
     return ( $self, $self->{data}, $args ) if $self and $self->{is_cached};
 
     $args->{worksheet} ||= 1;
-    $data = Spreadsheet::HTML::File::Loader::_parse( $args ) if $args->{file};
+    $data = Spreadsheet::HTML::File::Loader::_parse( $args, $data ) if $args->{file};
     $data = [ $data ] unless ref($data) eq 'ARRAY';
     $data = [ $data ] unless ref($data->[0]) eq 'ARRAY';
 
@@ -362,13 +362,14 @@ Object oriented interface:
 
     use Spreadsheet::HTML;
 
-    $generator = Spreadsheet::HTML->new( data => \@data, encode => 1 );
+    my @data = ( [qw(foo b&r b&z)], [1,2,3], [4,5,6], [7,8,9] );
+    my $gen  = Spreadsheet::HTML->new( data => \@data, encode => 1 );
 
-    print $generator->portrait( indent => '   ' );
-    print $generator->landscape( indent => "\t" );
+    print $gen->portrait( indent => '   ' );
+    print $gen->landscape( indent => "\t" );
 
-    $generator = Spreadsheet::HTML->new( file => 'data.xls', worksheet => 2 );
-    print $generator->generate( preserve => 1 );
+    $gen = Spreadsheet::HTML->new( file => 'data.xls', worksheet => 2 );
+    print $gen->generate( preserve => 1 );
 
 Procedural interface:
 
@@ -410,7 +411,14 @@ your default browser:
 
   $ mktable beadwork --param preset=dk --display
 
-Run C<mktable --man> for more documentation.
+Run C<mktable --man> for more documentation. You can also use this tool to quickly look
+up documentation for methods and (most) parameters:
+
+  $ mktable --help handson
+
+  $ mktable --help theta
+
+  $ mktable --help td
 
 =item * C<benchmark-spreadsheet-html>
 
@@ -436,40 +444,40 @@ generating methods below:
 
 =item * C<generate( %params )>
 
-Generate an HTML table with headings positioned at the top.
+Generate an HTML table.
 
   print $generator->generate();
 
 =item * C<portrait( %params )>
 
-Alias for C<generate()>.
+Generate an HTML table with headings positioned at the top.
 
   print $generator->portrait();
 
-=item * C<north( %params )>
-
-Alias for C<generate()>.
-
-  print $generator->north();
-
 =for html
 <table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td></tr><tr><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td></tr><tr><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
 
+=item * C<north( %params )>
+
+Alias for C<portrait()>.
+
+  print $generator->north();
+
 =item * C<landscape( %params )>
 
 Generate an HTML table with headings positioned at the left.
 
   print $generator->landscape();
 
+=for html
+<table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
+
 =item * C<west( %params )>
 
 Alias for C<landscape>.
 
   print $generator->west();
 
-=for html
-<table style="border: 1px dashed #A0A0A0"><tr><td><b>&nbsp;&nbsp;heading1&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col1&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col1&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading2&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col2&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col2&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading3&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col3&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col3&nbsp;&nbsp;</td></tr><tr><td><b>&nbsp;&nbsp;heading4&nbsp;&nbsp;</b></td><td>&nbsp;&nbsp;row1col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row2col4&nbsp;&nbsp;</td><td>&nbsp;&nbsp;row3col4&nbsp;&nbsp;</td></tr></table>
-
 =item * C<south( %params )>
 
 Generate an HTML table with headings positioned at the bottom.
@@ -530,13 +538,29 @@ See L<DBIx::HTML> for formatting your SQL database queries.
 =item * C<block>
 
 Integer. Can be supplied in conjunction with C<file> for image
-formats (JPEG, PNG and GIF). Defaults to 8. Must be larger than 1.
+formats (JPEG, PNG and GIF). Defaults to 8. Cannot be less than 1.
 Representing an image as an HTML table on a pixel by pixel basis
 tends to produce tables that are too large. This parameter can be
-used to increase and decrease that size.
+used to increase and decrease that size, by reading in blocks of
+pixels (8x8=64 pixels to be represented by one table cell) and
+determines the pixel color for that block. The smaller the
+block size the longer the processing time.
 
   block => 4
 
+=item * C<blend>
+
+Boolean. Default false. Can be supplied in conjuction with C<block>
+to change the algorithm for determining block's pixel color. When
+set to true, the pixel color is determined by the average color of
+all pixels in that block. When false (default), the pixel color is
+determined by finding the the most use color in the block.
+
+  blend => 1
+
+Turning C<blend> on tends to work better for photo realism. Keep it
+off for producing 1980's style pixel art images.
+
 =item * C<worksheet>
 
 Integer. Can be supplied in conjunction with C<file>. If multiple
@@ -650,6 +674,20 @@ Set value to C<undef> to avoid any substitutions.
 
   empty => '&#160;'
 
+=item * C<matrix>
+
+Boolean. Render the headings row with only <td> tags, no <th> tags.
+
+  matrix => 1
+
+=item * C<headless>
+
+Boolean. Render the table with without the headings row at all. 
+Any configuration to C<headings> or C<-r0> will be discarded with
+the headings row.
+
+  headless => 1
+
 =item * C<tgroups>
 
 Integer. Group table rows into <thead>, <tbody> and <tfoot> sections.
@@ -680,20 +718,6 @@ Useful for loading data from files only once.
 
   cache => 1
 
-=item * C<matrix>
-
-Boolean. Render the headings row with only <td> tags, no <th> tags.
-
-  matrix => 1
-
-=item * C<headless>
-
-Boolean. Render the table with without the headings row at all. 
-The first row after the headings is still C<-r1>, and
-any configuration to C<headings> or C<-r0> will be discarded.
-
-  headless => 1
-
 =item * C<scroll>
 
 Boolean. Scrolls the table cells. See L<Spreadsheet::HTML::Presets::Scroll>.
@@ -722,8 +746,8 @@ parameters use leading dashes.
 =item * C<sorted_attrs>
 
 Boolean. This is useful for ensuring that attributes within tags are
-rendered in alphabetical ordering, for consistancy. You will
-most likely never need this feature.
+rendered in alphabetical order, for consistancy. You will most likely
+never need this feature.
 
   sorted_attrs
 
@@ -892,9 +916,9 @@ the attributes of the <tr> tag within the <tfoot> group.
 
 =back
 
-=head2 PRESETS
+=head1 PRESET METHODS
 
-The following presets are availble for creating tables that can be used
+The following preset methods are availble for creating tables that can be used
 with little to no additional coding. All preset methods accept all of the
 above mentioned parameters (%params) in addition to those specific to themselves.
 
@@ -906,7 +930,7 @@ Generate layout tables.
 
 =item * C<list( ordered, col, row, %params )>
 
-Generate <ol> and <ul> list.
+Generate <ol> and <ul> lists.
 
 =item * C<select( col, row, values, selected, placeholder, optgroup, label, %params )>
 
@@ -1005,8 +1029,6 @@ Uses the following optional modules:
 
 =over 4
 
-=item * L<Imager>
-
 =item * L<Text::CSV>
 
 =item * L<Text::CSV_XS>
@@ -1023,6 +1045,8 @@ Uses the following optional modules:
 
 =item * L<HTML::TableExtract>
 
+=item * L<Imager>
+
 =back
 
 The following are used by some presets to enhance output, if installed:
