@@ -7,7 +7,7 @@ eval "use Spreadsheet::Read";
 our $NOT_AVAILABLE = $@;
 
 sub _parse {
-    my $args = shift;
+    my ($args,$data) = @_;
     my $file = $args->{file};
 
     if ($file =~ /\.html?$/) {
@@ -17,7 +17,7 @@ sub _parse {
     } elsif ($file =~ /\.ya?ml$/) {
         return Spreadsheet::HTML::File::YAML::_parse( $args );
     } elsif ($file =~ /\.(gif|png|jpe?g)$/) {
-        return Spreadsheet::HTML::File::Image::_parse( $args );
+        return Spreadsheet::HTML::File::Image::_parse( $args, $data );
     }
 
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file or $file eq '-';
@@ -133,18 +133,24 @@ Parses with (requires) L<Imager::File::JPEG>.
 
   generate( file => 'foo.jpg' )
   generate( file => 'foo.jpeg' )
+  generate( file => 'foo.jpeg', block => 2 )
+  generate( file => 'foo.jpeg', block => 2, blend => 1 )
 
 =item * PNG
 
 Parses with (requires) L<Imager::File::PNG>.
 
   generate( file => 'foo.png' )
+  generate( file => 'foo.png', block => 2 )
+  generate( file => 'foo.png', block => 2, blend => 1 )
 
 =item * GIF
 
 Parses with (requires) L<Imager::File::GIF>.
 
   generate( file => 'foo.gif' )
+  generate( file => 'foo.gif', block => 2 )
+  generate( file => 'foo.gif', block => 2, blend => 1 )
 
 =back
 
@@ -244,7 +250,7 @@ eval "use Imager";
 our $NOT_AVAILABLE = $@;
 
 sub _parse {
-    my $args = shift;
+    my ($args,$data) = @_;
     my $file = $args->{file};
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
     return [[ "cannot load $file" ],[ 'please install Imager' ]] if $NOT_AVAILABLE;
@@ -252,7 +258,7 @@ sub _parse {
     my $imager = Imager->new;
     my $image  = $imager->read( file => $file ) or return [[ "cannot load $file" ],[ $imager->errstr ]];
 
-    $args->{block} = $args->{block} && $args->{block} =~ /\D/ ? 8 : ($args->{block} || 0) < 2 ? 8 : $args->{block};
+    $args->{block} = $args->{block} && $args->{block} =~ /\D/ ? 8 : ($args->{block} || 0) < 1 ? 8 : $args->{block};
     $args->{fill}  = join( 'x', int( $image->getheight / $args->{block} ), int( $image->getwidth / $args->{block} ) );
     $args->{table} = { cellspacing => 0, border => 0, cellpadding => 0 };
 
@@ -269,25 +275,43 @@ sub _parse {
                 }
             }
 
-            my %block;
-            for my $pixel ($image->getpixel( x => \@x, y => \@y )) {
-                next unless ref $pixel;
-                my $color = '#' . join '', map sprintf( "%02X", $_ ), ($pixel->rgba)[0..2];
-                $block{$color}++;
+            my $primary;
+            if ($args->{block} == 1) {
+                $primary = join '', map sprintf( "%02X", $_ ), ($image->getpixel( x => $x[0], y => $y[0] )->rgba)[0..2];
+            } else {
+                if ($args->{blend}) {
+                    my %average = ( r => 0, g => 0, b => 0 );
+                    for my $pixel ($image->getpixel( x => \@x, y => \@y )) {
+                        next unless ref $pixel;
+                        my @rgba = $pixel->rgba;
+                        $average{r} += $rgba[0];
+                        $average{g} += $rgba[1];
+                        $average{b} += $rgba[2];
+                    }
+                    $_ /= ($args->{block} * $args->{block}) for values %average;
+                    $primary = join '', map sprintf( "%02X", $_ ), @average{qw(r g b)};
+                } else {
+                    my %block;
+                    for my $pixel ($image->getpixel( x => \@x, y => \@y )) {
+                        next unless ref $pixel;
+                        my $color = join '', map sprintf( "%02X", $_ ), ($pixel->rgba)[0..2];
+                        $block{$color}++;
+                    }
+                    $primary = (sort { $block{$b} <=> $block{$a} } keys %block)[0];
+                }
             }
 
-            my $color = (sort { $block{$b} <=> $block{$a} } keys %block)[0];
             $args->{"-r${c}c${r}"} = {
                 width  => $args->{block} * 2,
                 height => $args->{block},
-                style  => { 'background-color' => $color },
+                style  => { 'background-color' => '#' . $primary },
             };
             $c++;
         }
         $r++;
     }
 
-    return [];
+    return $data;
 }
 
 1;
